@@ -44,6 +44,8 @@ function onFrame(event) {
 	
 	wiggleTurtle(event.count, isGoing);
 	
+	var speedMult = event.delta*60.0 * 2;
+	
 	if(isGoing){
 		if(movOrRotate){
 			// Each frame, move the path 1/30th of the difference in position
@@ -57,8 +59,8 @@ function onFrame(event) {
 			// destination point:
 			var distance = (movDestination - turtle.position).length;
 			var isArrived = false;
-			if(distance>speed){
-				turtle.position += movVector.normalize(speed);
+			if(distance>speed*speedMult){
+				turtle.position += movVector.normalize(speed*speedMult);
 			}else{
 				turtle.position = movDestination
 				isArrived = true;
@@ -137,8 +139,8 @@ function onFrame(event) {
 		}else{
 			var distance = (rotDestination - curRotation)
 			var isArrived = false;
-			if(Math.abs(distance)>rotspeed){
-				rotDelta = distance > 0 ? rotspeed : -rotspeed;
+			if(Math.abs(distance)>rotspeed*speedMult){
+				rotDelta = distance > 0 ? rotspeed*speedMult : -rotspeed*speedMult;
 				turtle.rotate(rotDelta);
 				curRotation += rotDelta;
 			}else{
